# Nextcloud All-in-One with Tailscale Integration

![Nextcloud All-in-One with Tailscale](https://nextcloud.com/c/uploads/2023/02/logo_nextcloud_white.svg "Nextcloud All-in-One")

This project sets up a Nextcloud All-in-One instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your Nextcloud All-in-One instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
nextcloud-aio/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/     # Persistent Tailscale state
│   └── config/             # Tailscale configuration files
└── nextcloud-all-in-one/
    └── config/             # Nextcloud All-in-One configuration files
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/nextcloud-all-in-one
   cd nextcloud-aio
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations
        - CAUTION: Changing `"${TS_CERT_DOMAIN}:443": false` to `true` will expose the service to the internet

4. Configure Nextcloud All-in-One
    - See the [README in the Repo](https://github.com/nextcloud/all-in-one#nextcloud-all-in-one) for configuration options

5. Start the Services
    ```bash
    docker compose up -d
    ```

6. Wait for Certificate to propagate [~2m] 

7. Login 
    - After starting the services your service should be available via tailnet at https://nextcloud-all-in-one.{{YOUR_TAILNET_DOMAIN}}.ts.net ie https://nextcloud-all-in-one.tail12345.ts.net/

## Services

### nextcloud-all-in-one-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: nextcloud-all-in-one-ts
- Hostname: nextcloud-all-in-one
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### nextcloud-all-in-one

- Depends on nextcloud-all-in-one-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://nextcloud-all-in-one.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://nextcloud-all-in-one.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs nextcloud-all-in-one-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 3000:3000
    ```
- Stopping the Services
    ```bash
    docker compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs nextcloud-all-in-one-ts
    docker logs nextcloud-all-in-one
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting

## Notes
- The Nextcloud All-in-One service uses the Tailscale service's network stack via `network_mode: service:nextcloud-all-in-one-ts`
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
    - Tailscale documentation: https://tailscale.com/kb/
    - Nextcloud All-in-One [documentation](https://nextcloud.com/blog/how-to-install-the-nextcloud-all-in-one-on-linux/)
    - Nextcloud All-in-One [repository](https://github.com/nextcloud/all-in-one#nextcloud-all-in-one)